@@ -1,7 +1,7 @@
 /*
  * DEBUG: section 93    eCAP Interface
  */
-#include "squid-old.h"
+#include "squid.h"
 #include "HttpRequest.h"
 #include "HttpReply.h"
 #include "BodyPipe.h"
@@ -13,6 +13,7 @@
 #include "adaptation/ecap/XactionRep.h"
 #include "adaptation/ecap/Host.h" /* for protocol constants */
 #include "base/TextException.h"
+#include "URL.h"
 
 /* HeaderRep */
 
@@ -110,7 +111,6 @@ Adaptation::Ecap::HeaderRep::TranslateHeaderId(const Name &name)
     return HDR_OTHER;
 }
 
-
 /* FirstLineRep */
 
 Adaptation::Ecap::FirstLineRep::FirstLineRep(HttpMsg &aMessage): theMessage(aMessage)
@@ -192,7 +192,6 @@ Adaptation::Ecap::FirstLineRep::TranslateProtocolId(const Name &name)
     return AnyP::PROTO_UNKNOWN;
 }
 
-
 /* RequestHeaderRep */
 
 Adaptation::Ecap::RequestLineRep::RequestLineRep(HttpRequest &aMessage):
@@ -283,7 +282,6 @@ Adaptation::Ecap::RequestLineRep::protocol(const Name &p)
     FirstLineRep::protocol(p);
 }
 
-
 /* ReplyHeaderRep */
 
 Adaptation::Ecap::StatusLineRep::StatusLineRep(HttpReply &aMessage):
@@ -363,7 +361,6 @@ Adaptation::Ecap::BodyRep::bodySize() const
     return !theBody ? BodySize() : BodySize(theBody->bodySize());
 }
 
-
 /* MessageRep */
 
 Adaptation::Ecap::MessageRep::MessageRep(HttpMsg *rawHeader):
